@@ -12,10 +12,8 @@ Usage::
 import sys
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_datapipeline.literals import OperatorType
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -65,9 +63,7 @@ class FieldTypeDef(_RequiredFieldTypeDef, _OptionalFieldTypeDef):
 
 
 OperatorTypeDef = TypedDict(
-    "OperatorTypeDef",
-    {"type": Literal["EQ", "REF_EQ", "LE", "GE", "BETWEEN"], "values": List[str]},
-    total=False,
+    "OperatorTypeDef", {"type": OperatorType, "values": List[str]}, total=False
 )
 
 ParameterAttributeTypeDef = TypedDict("ParameterAttributeTypeDef", {"key": str, "stringValue": str})
